/*====================================================================

ObjectWeb Deployment Framework
Copyright (C) 2004-2006 INRIA - USTL - LIFL - GOAL
Contact: deployment@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Frdric Briclet.
Contributor(s): Eric Bruneton.

====================================================================
$Id: AbstractBindingSetterTask.java,v 1.2 2006/02/16 18:13:18 merle Exp $
====================================================================*/

package org.objectweb.deployment.scheduling.component.lib;

import org.objectweb.deployment.scheduling.component.api.BindingSetterTask;
import org.objectweb.deployment.scheduling.component.api.BindingProviderTask;

/**
 * AbstractBindingSetterTask implements BindingSetterTask.
 *
 * Subclasses must implement:
 * - public void execute(Object context) throws Exception;
 *
 * @author <a href="mailto:Philippe.Merle@inria.fr">Philippe Merle</a>
 * @author <a href="mailto:Frdric.Briclet@lifl.fr">Frdric Briclet</a>
 *
 * @version 0.2
 */

public abstract class AbstractBindingSetterTask
              extends AbstractConfigurationTask
           implements BindingSetterTask
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Reference to the binding provider task. */
    private BindingProviderTask bindingProviderTask_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    AbstractBindingSetterTask()
    {
        // Call the default AbstractConfigurationTask constructor.
        super();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.deployment.scheduling.component.api.BindingSetterTask
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.deployment.scheduling.component.api.RequireBindingProviderTask
    //
    // ==================================================================

    /**
     * Return the component binding provider task.
     *
     * @return The component binding provider task.
     */
    public BindingProviderTask
    getBindingProviderTask()
    {
        return bindingProviderTask_;
    }

    /**
     * Set the component binding provider task.
     *
     * @param task - The component binding provider task.
     */
    public void
    setBindingProviderTask(BindingProviderTask task)
    {
        if(bindingProviderTask_ != null)
            removePreviousTask(bindingProviderTask_);

        bindingProviderTask_ = task;

        if(bindingProviderTask_ != null)
            addPreviousTask(bindingProviderTask_);
    }

    // ==================================================================
    //
    // Public methods for org.objectweb.deployment.scheduling.component.api.ConfigurationTask
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.deployment.scheduling.component.api.RequireInstanceProviderTask
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.deployment.scheduling.core.api.Task
    //
    // ==================================================================

    /**
     * Execute the task.
     *
     * Must be implemented by subclasses.
     *
     * @param context - The context in which the task will be executed.
     *
     * @throws Exception - Thrown if a problem obscurs during execution.
     */
    // public abstract void
    // execute(Object context)
    // throws Exception;

    /**
     * Return the result of the execution.
     *
     * @return The result of the execution.
     */
    public Object
    getResult()
    {
        // This task produces no result.
        return null;
    }

    /**
     * Set the result of the execution.
     *
     * @param result - The result of the execution.
     *
     * TODO: Is it really useful to provide this method?
     */
    public void
    setResult(Object result)
    {
        // Nothing to do.
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
