/***
 * Fractal ADL Parser
 * Copyright (C) 2002-2006 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Eric Bruneton
 *
 * Contributor: Philippe Merle
 *
 * ---------------------------------------------------------------------------
 * $Id: ADLException.java,v 1.2 2006/02/16 13:49:10 merle Exp $
 * ---------------------------------------------------------------------------
 */

package org.objectweb.fractal.adl;

import java.io.PrintStream;
import java.io.PrintWriter;

/**
 * Thrown when an error occurs during the analysis of an ADL definition.
 */

public class ADLException extends Exception {
  
  /**
   * The exception that caused this exception. May be <tt>null</tt>.
   */
  
  private Exception exception;

  /**
   * Constructs a new {@link ADLException}.
   * 
   * @param msg a detail message.
   * @param src where the error is located.
   */
  
  public ADLException (final String msg, final Node src) {
    super(src == null ? msg : msg + " (" + src.astGetSource() + ")");
  }
  
  /**
   * Constructs a new {@link ADLException}.
   * 
   * @param msg a detail message.
   * @param src where the error is located.
   * @param e the exception that caused this exception.
   */
  
  public ADLException (final String msg, final Node src, final Exception e) {
    super(src == null ? msg : msg + " (" + src.astGetSource() + ")");
    this.exception = e;
  }
  
  /**
   * Prints the stack backtrace.
   */

  public void printStackTrace () {
    if (exception != null) {
      System.err.println(this);
      exception.printStackTrace();
    } else {
      super.printStackTrace();
    }
  }

  /**
   * Prints this exception and its backtrace to the specified print stream.
   *
   * @param s <tt>PrintStream</tt> to use for output.
   */

  public void printStackTrace (final PrintStream s) {
    if (exception != null) {
      s.println(this);
      exception.printStackTrace(s);
    } else {
      super.printStackTrace(s);
    }
  }

  /**
   * Prints this exception and its backtrace to the specified print writer.
   *
   * @param s <tt>PrintWriter</tt> to use for output.
   */

  public void printStackTrace (final PrintWriter s) {
    if (exception != null) {
      s.write(this + "\n");
      exception.printStackTrace(s);
    } else {
      super.printStackTrace(s);
    }
  }
}
